@@ -319,6 +319,18 @@ void	xmlXPathRegisterVariableLookup	(xmlXPathContextPtr ctxt,
 					 xmlXPathVariableLookupFunc f,
 					 void *varCtxt);
 
+/*
+ * Function Lookup forwarding
+ */
+typedef xmlXPathFunction
+	(*xmlXPathFuncLookupFunc)	(void *ctxt,
+					 const xmlChar *name,
+					 const xmlChar *ns_uri);
+
+void	xmlXPathRegisterFuncLookup	(xmlXPathContextPtr ctxt,
+					 xmlXPathFuncLookupFunc f,
+					 void *funcCtxt);
+
 /*
  * Error reporting
  */
@@ -337,6 +349,8 @@ void		xmlXPathDebugDumpCompExpr(FILE *output,
 /**
  * NodeSet handling
  */
+int		xmlXPathNodeSetContains		(xmlNodeSetPtr cur,
+						 xmlNodePtr val);
 xmlNodeSetPtr	xmlXPathDifference		(xmlNodeSetPtr nodes1,
 						 xmlNodeSetPtr nodes2);
 xmlNodeSetPtr	xmlXPathIntersection		(xmlNodeSetPtr nodes1,
